
#include "mbed.h"
#include "EthernetInterface.h"
#include "SNTPClient.h"
#include "DHT.h"

#define ENABLE_NTP
#define ENABLE_DHT

#define INTERVAL_TIME           1.0
#define INTERVAL_PROC			1.0

Ticker flipper;
EthernetInterface eth;
tstamp g_seconds=0;

#ifdef ENABLE_DHT
DHT sensor(D4, DHT11);
#endif

void flip() {
    g_seconds += 1;
}

void baud(int baudrate) {
    Serial s(USBTX, USBRX);
    s.baud(baudrate);
}

int main (void)
{
    datetime time;
    int ret;
    uint8_t mac_addr[6] = {0x00, 0x08, 0xDC, 0x01, 0x02, 0x03}; 
#ifdef ENABLE_DHT
    int error = 0;
    float h = 0.0f, c = 0.0f;
#endif
	
    baud(115200);

    printf("#Wait a second...\r\n");
    eth.init(mac_addr); //Use DHCP
    eth.connect();
    printf("IP Address is %s\r\n", eth.getIPAddress());
    
#ifdef ENABLE_NTP
    SNTPClient sntp("time.nist.gov", 40);   // timezone: Korea, Republic of
    //SNTPClient sntp("kr.pool.ntp.org", 40);   // timezone: Korea, Republic of
    sntp.connect();

    do {
        ret = sntp.getTime(&time);
        wait(0.1);
    }while(ret != true);
    printf("1st %d/%d/%d %d:%d:%d \r\n", time.yy, time.mo, time.dd, time.hh, time.mm, time.ss);
#endif   

	flipper.attach(&flip, INTERVAL_TIME);
    
    while (true)
    {
#ifdef ENABLE_NTP
        sntp.calcdatetime(g_seconds);
        sntp.getTime2(&time);
        
        printf("%d/%d/%d %d:%d:%d\r\n", time.yy, time.mo, time.dd, time.hh, time.mm, time.ss);
#endif        

#ifdef ENABLE_DHT
        error = sensor.readData();
        if (0 == error) {
			c	= sensor.ReadTemperature();
			h	= sensor.ReadHumidity();
			printf("Temperature in Celcius: %4.2f\r\n", c);
			printf("Humidity is %4.2f\r\n", h);
        } else {
            printf("Error: %d\r\n", error);
        }
#endif

		wait(INTERVAL_PROC);
	
    }
}
